==> kmymoney-5.0.4.tar.xz: kmymoney-5.0.4/kmymoney/plugins/icalendar/export/icalendarexporter.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "onet.cristian@gmail.com",
                "Name": "Cristian Oneț",
                "Name[ca@valencia]": "Cristian Oneț",
                "Name[ca]": "Cristian Oneț",
                "Name[cs]": "Cristian Oneț",
                "Name[en_GB]": "Cristian Oneț",
                "Name[es]": "Cristian Oneț",
                "Name[fr]": "Cristian Oneț",
                "Name[gl]": "Cristian Oneț",
                "Name[it]": "Cristian Oneț",
                "Name[nl]": "Cristian Oneț",
                "Name[pl]": "Cristian Oneț",
                "Name[pt]": "Cristian Oneț",
                "Name[pt_BR]": "Cristian Oneț",
                "Name[ru]": "Cristian Oneț",
                "Name[sk]": "Cristian Oneț",
                "Name[sv]": "Cristian Oneț",
                "Name[uk]": "Cristian Oneț",
                "Name[x-test]": "xxCristian Onețxx"
            }
        ],
        "Description": "Exports schedules to iCalendar files",
        "Description[ca@valencia]": "Exporta les planificacions a fitxers iCalendar",
        "Description[ca]": "Exporta les planificacions a fitxers iCalendar",
        "Description[en_GB]": "Exports schedules to iCalendar files",
        "Description[es]": "Exporta planificaciones a archivos iCalendar",
        "Description[fr]": "Exporte des calendriers dans des fichiers « iCalendar »",
        "Description[gl]": "Exporta planificacións a ficheiros iCalendar",
        "Description[it]": "Esporta le pianificazioni a file iCalendar",
        "Description[ko]": "iCalendar 파일로 예약 내보내기",
        "Description[nl]": "Exporteert planningen naar iCalender bestanden",
        "Description[pl]": "Eksportuje harmonogramy do plików iCalendar",
        "Description[pt]": "Exporta os agendamentos para ficheiros do iCalendar",
        "Description[pt_BR]": "Exporta agendamentos para arquivos iCalendar",
        "Description[sk]": "Exportovať rozvrhy do súborov iCalendar",
        "Description[sv]": "Exporterar scheman till iCalendar-filer",
        "Description[uk]": "Експортування розкладів до файлів iCalendar",
        "Description[x-test]": "xxExports schedules to iCalendar filesxx",
        "EnabledByDefault": true,
        "Icon": "x-office-calendar",
        "Id": "icalendarexporter",
        "License": "GPL",
        "Name": "iCalendar",
        "Name[ca@valencia]": "iCalendar",
        "Name[ca]": "iCalendar",
        "Name[cs]": "iCalendar",
        "Name[en_GB]": "iCalendar",
        "Name[es]": "iCalendar",
        "Name[fr]": "iCalendar",
        "Name[gl]": "iCalendar",
        "Name[it]": "iCalendar",
        "Name[nl]": "iCalendar",
        "Name[pl]": "iCalendar",
        "Name[pt]": "iCalendar",
        "Name[pt_BR]": "iCalendar",
        "Name[sk]": "iCalendar",
        "Name[sv]": "iCalendar",
        "Name[uk]": "iCalendar",
        "Name[x-test]": "xxiCalendarxx",
        "ServiceTypes": [
            "KMyMoney/Plugin"
        ],
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    }
}

==> kmymoney_5.0.8.orig.tar.xz: kmymoney-5.0.8/kmymoney/plugins/icalendar/export/icalendarexporter.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "onet.cristian@gmail.com",
                "Name": "Cristian Oneț",
                "Name[ca@valencia]": "Cristian Oneț",
                "Name[ca]": "Cristian Oneț",
                "Name[cs]": "Cristian Oneț",
                "Name[de]": "Cristian Oneț",
                "Name[en_GB]": "Cristian Oneț",
                "Name[es]": "Cristian Oneț",
                "Name[fr]": "Cristian Oneț",
                "Name[gl]": "Cristian Oneț",
                "Name[it]": "Cristian Oneț",
                "Name[nl]": "Cristian Oneț",
                "Name[pl]": "Cristian Oneț",
                "Name[pt]": "Cristian Oneț",
                "Name[pt_BR]": "Cristian Oneț",
                "Name[ru]": "Cristian Oneț",
                "Name[sk]": "Cristian Oneț",
                "Name[sv]": "Cristian Oneț",
                "Name[uk]": "Cristian Oneț",
                "Name[x-test]": "xxCristian Onețxx"
            }
        ],
        "Description": "Exports schedules to iCalendar files",
        "Description[ca@valencia]": "Exporta les planificacions a fitxers iCalendar",
        "Description[ca]": "Exporta les planificacions a fitxers iCalendar",
        "Description[de]": "Exportiert geplante Buchungen in iCalendar-Dateien",
        "Description[en_GB]": "Exports schedules to iCalendar files",
        "Description[es]": "Exporta planificaciones a archivos iCalendar",
        "Description[fr]": "Exporte des calendriers dans des fichiers « iCalendar »",
        "Description[gl]": "Exporta planificacións a ficheiros iCalendar",
        "Description[it]": "Esporta le pianificazioni a file iCalendar",
        "Description[ko]": "iCalendar 파일로 예약 내보내기",
        "Description[nl]": "Exporteert planningen naar iCalender bestanden",
        "Description[pl]": "Eksportuje harmonogramy do plików iCalendar",
        "Description[pt]": "Exporta os agendamentos para ficheiros do iCalendar",
        "Description[pt_BR]": "Exporta agendamentos para arquivos iCalendar",
        "Description[sk]": "Exportovať rozvrhy do súborov iCalendar",
        "Description[sv]": "Exporterar scheman till iCalendar-filer",
        "Description[uk]": "Експортування розкладів до файлів iCalendar",
        "Description[x-test]": "xxExports schedules to iCalendar filesxx",
        "EnabledByDefault": true,
        "Icon": "x-office-calendar",
        "Id": "icalendarexporter",
        "License": "GPL",
        "Name": "iCalendar",
        "Name[ca@valencia]": "iCalendar",
        "Name[ca]": "iCalendar",
        "Name[cs]": "iCalendar",
        "Name[de]": "iCalendar",
        "Name[en_GB]": "iCalendar",
        "Name[es]": "iCalendar",
        "Name[fr]": "iCalendar",
        "Name[gl]": "iCalendar",
        "Name[it]": "iCalendar",
        "Name[nl]": "iCalendar",
        "Name[pl]": "iCalendar",
        "Name[pt]": "iCalendar",
        "Name[pt_BR]": "iCalendar",
        "Name[sk]": "iCalendar",
        "Name[sv]": "iCalendar",
        "Name[uk]": "iCalendar",
        "Name[x-test]": "xxiCalendarxx",
        "ServiceTypes": [
            "KMyMoney/Plugin"
        ],
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    }
}
